@@ -6,7 +6,11 @@
 #' can be obtained from. The full syntax of a reference is `type::ref`, but
 #' `type` can be often omitted, the common ref types have shortcuts.
 #'
-#' @includeRmd tools/doc/pkg-refs.Rmd
+#' @details
+#' ```{r child = "tools/doc/pkg-refs.Rmd"}
+#' ```
+#' `r doc_share_rmd("tools/doc/pkg-refs.Rmd", "inst/docs/pkg-refs.rds")`
+#'
 #' @name pkg_refs
 NULL
 
@@ -102,9 +106,10 @@ github_url_rx <- function() {
     "(?:(?<package>", package_name_rx(), ")=)?",
     ## Optional remote type
     "(?:github::)?",
-    ## Optional protocol
-    "(?:(?:https?://)|(?:ssh://(?:[^@]+@)?)?)",
+    ## Protocol
+    "(?:(?:https?://)|(?:(?:ssh://|[^@]+@)))",
     ## Servername
+    ## TODO: should probably restrict this is (configurable) GH servers
     "(?:[^/:]+)[/:]",
     ## Username
     github_username_rx(), "/",
@@ -137,6 +142,8 @@ local_rx <- function() {
   sugar <- "(?<path>(?:/|\\\\|~|[.]/|[.]\\\\|[.]$).*)"
   paste0(
     "^",
+    ## Optional package name
+    "(?:(?<package>", package_name_rx(), ")=)?",
     "(?|", typed, "|", sugar, ")",
     "$"
   )
@@ -160,7 +167,10 @@ get_remote_types <- function(refs) {
   types[types == "" & grepl(param_rx(), refs, perl = TRUE)] <- "param"
 
   if (any(bad <- types == "")) {
-    stop("Can't parse remotes: ", paste(refs[bad], collapse = ", "))
+    throw(pkg_error(
+      "Cannot parse package{?s}: {.pkg {refs[bad]}}.",
+      i = msg_package_sources()
+    ))
   }
 
   types
@@ -197,7 +207,10 @@ parse_pkg_refs <- function(refs, remote_types = NULL, ...) {
   res <- vector("list", length(refs))
 
   if (length(bad <- setdiff(unique_types, names(remote_types)))) {
-    stop("Unknown remote type(s): ", format_items(bad))
+    throw(pkg_error(
+      "Unknown package source{?}: {.val {bad}}.",
+      i = msg_package_sources()
+    ))
   }
 
   for (this in unique_types) {
@@ -245,7 +258,10 @@ parse_ref_params <- function(refs) {
 
 add_ref_params <- function(res, params) {
   if (length(res) != length(params)) {
-    stop("Internal error, param length mismath")
+    throw(pkg_error(
+      "Internal error in the parameter parser, parameter length mismath.",
+      i = msg_internal_error()
+    ))
   }
   for (i in seq_along(res)) {
     res[[i]]$params <- if (length(params[[i]])) params[[i]] else character()
